Chapter 6 - SCREEN ENHANCEMENTS


Introduction

Application programs frequently make use of video enhancements or
colors to highlight important information on the screen.  The
enhanced information can be anything from an error message or
misspelled word to a pop-up window offering menu selections.  To a
sighted person, the intent and position of such an enhancement is
obvious; to a blind person it can be a mystery.  Since Jaws has
been designed specifically with the needs of the blind user in
mind, several tools have been provided to assist with enhancements.

The Enhancements Menu

Selecting "Enhance" from the Jaws Main Menu will bring up the Jaws
Enhancement Menu.  The choices offered on this menu provide tools
to search for and speak video enhancements.  Jaws will
automatically sense whether the computer is using a color or a
monochrome monitor and offer choices accordingly.  If you think
that it has selected incorrectly refer to the section on "Color or
Monochrome" in the Trouble Shooting chapter, or "Command Line
Parameters".  The Enhancement menu offers the following selections:

Different - Search for an enhancement different from the current
one.

Find      - Search for a specific enhancement or color.

Repeat    - Repeat the previous enhancement search.

Different Enhancements

Many times it is not necessary to know which type of enhancement to
search for - all that matters is that the enhancement is different
from the enhancement under the active cursor.  The selection
"Different" on the Enhancement menu will perform such a search.

Next you will be asked for Options, see the section below about
that.  After any options are specified and the Enter key is
pressed, Jaws will exit the menu system and perform the search.  If
the search is successful, the Jaws Cursor will be positioned where
the first occurrence of the different enhancement is found;
otherwise, an error tone will be produced. 

Finding an Enhancement

On other occasions, you may know exactly which enhancement to
expect but you don't want to stop for others which might be on the
screen.  For example, if you're working with the Word Perfect
spelling checker (which, on a monochrome monitor, highlights
misspelled words in reverse video) you would simply want to search
for the word which appears in reverse video.

The choice Find on the Enhancement menu will allow you to search
for a specific color or monochrome enhancement.  If this option is
selected, you will be asked to specify the enhancement to search
for and then prompted for Options.  Depending on whether the
monitor you have is a color or a monochrome monitor, the
enhancement you will be asked to specify will be different.

If you are using a color monitor, you will be asked to specify
which color to search for; the choices will include B, L, G, Red,
Cyan, and several others.  Selecting B, L, or G will allow you to
choose from colors which begin with either B, L, or G (such as
Black, Blue, Brown, etc.;  Light Green, Light Magenta, etc.;  or
Green or Grey).  Next you will be prompted for Options, see the
section below.  

If you are using a monochrome monitor, you will be asked to specify
which monochrome enhancement to search for.  These will include: 
Reverse, Normal, Intense, Underlined, and Blinking.  When Jaws
searches, it will look for the first occurrence of that enhancement
- either alone or in combination with other enhancements (if
searching for intense, Jaws will find something which is blinking-
intense).

After specifying the enhancement to search for, you will be
prompted for Options, see below for the choices.  

After any options are specified and the Enter key is pressed, Jaws
will perform the search.  If the active cursor is already
positioned on the desired enhancement, Jaws will search for the
next occurrence of that enhancement.  If the search is successful,
the menu system will be exited and the Jaws Cursor will be
positioned at the first occurrence of the desired enhancement;
otherwise, the menu system will be exited, an error tone will be
produced, and the cursor will be restored to its original position.

When using a macro to perform these searches the audio will be
silenced, you will not hear the error tone or the enhanced data
when found.  You can then use the macro to speak or do whatever you
want, if anything, based on the results of the search.

Options

You can select the frame to search in, the start position and
direction, and whether to search in the background, foreground, or
either.

The currently active frame will be the default frame number.  From
the cursor position forward will be the default starting position
and direction.  The "background" is the default for color searches. 
Just press Enter when prompted for options to accept the defaults. 

To specify a different frame number just enter the number, 0-99. 
Or you can specify the frame that the cursor is currently in: "J"
for the Jaws cursor, "P" for the PC cursor, or "A" for the active
cursor, the one turned on.  Sometimes the cursor will be in more
than one frame, since they can overlap.  Then the frame with the
highest number has priority and will be chosen.

To specify a different starting position or direction enter the
following options:  "T" for Top of screen and forward; "B" for
Bottom of screen and backward; "C" for Cursor position and
backward.

You can also choose to search in the foreground, background, or
either.  This only works on color computers:  Just enter "F" for
foreground; "E" for either; The default is background, you do not
have to specify it.

The syntax for the Options line is very free-form, enter the frame
numbers first, then any of the letters needed to specify the other
choices. For example, "29tf" will search frame 29 from the top,
searching only in the foreground.  "PB" will search the frame the
PC cursor is in from the bottom searching in the background.

For more details and examples refer to "Search Options".

Repeat Previous Search

Occasionally, when you search for an enhancement or color, the
search may not find the desired enhancement - it may find an
occurrence of the enhancement before the desired one is found.  In
these cases, Jaws provides the item "Repeat" on the Enhancement
menu to repeat the previous search using the same enhancements and
options.

Jaws will, if the cursor is already positioned over the desired
enhancement, search for the next occurrence of that enhancement.
Again, if the search is successful, the menu system will be exited
and the Jaws Cursor will be positioned at the next occurrence of
the previously specified enhancement; otherwise, the menu system
will be exited and the cursor returned to its original position. 
This is very useful for finding the second or third or other
enhancement on the screen.  A macro would do the same thing with
just one keystroke.

Say Enhancements

In many cases, it is necessary to know what the enhancement is at
the current cursor position.  Holding down the insert key and
pressing the number 5 on the numbers row will cause the enhancement
under the active cursor to be spoken.  This is a Jaws function
called "Say color", it can be found in the Jaws function window of
the macro editor.  It can be used in a macro and combined with
other functions, or moved to another key, to suit your preferences
or the needs of the application.  Refer to the training tapes to
learn more about macros and configuring for specific applications.

Say Field Mode

Many application programs make use of "Color bars" or enhanced
areas of the screen to indicate current menu selections, errors, or
various other important items of information.  Jaws provides a
special mode of operation to help the user cope with such programs
called "Say Field Mode".  In this context, "Field" refers to a
group of characters or words that are all of the same color or
enhancement.

By holding down the Zero key and pressing the number 6 on the
numbers row, the Jaws Say Field mode can be turned on or off.  The
default is for Say Field mode to be turned off.  When Say Field
mode is on, Prior Word, Say Word, and Next Word become Prior Field,
Say Field, and Next Field.  When Say Field is pressed, all the text
within the current field (the field containing the active cursor)
will be read.  This is also a Jaws function and can be used in a
macro.

Color-Bar Tracking

Tracking a menu bar or color bar is a common need with today's
powerful application programs.  The powerful search criteria and
options make Jaws very good at this.  Almost any menu bar can be
tracked once you figure out which combination of frame number,
start position, direction, and foreground/background to use to
define the search.  Wrap these all up in a macro to conveniently
track any menu.

You can also use the Active Frame feature to restrict Jaws reading
to a certain part of the screen.  For example, in DBase 3+ Jaws
will follow the color bar highlighting the menu choice, but may
read data outside the current DBase window.  This can be confusing. 
By defining a frame around this DBase window and making that frame
active will stop this reading of extraneous data.
